pub trait UnsubscribeRpcMethod<M>:
Send
+ Sync
+ 'static {
type Out: Future<Output = Result<Value>> + Send + 'static;
// Required method
fn call(&self, id: SubscriptionId, meta: Option<M>) -> Self::Out;
}Expand description
Unsubscribe handler
Required Associated Types
Required Methods
Sourcefn call(&self, id: SubscriptionId, meta: Option<M>) -> Self::Out
fn call(&self, id: SubscriptionId, meta: Option<M>) -> Self::Out
Called when client is requesting to cancel existing subscription.
Metadata is not available if the session was closed without unsubscribing.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".